<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use App\Models\CronMatch;

class CronMatchController extends Controller
{
    /**
     * Display the form for creating a new match.
     */
    public function create()
    {
        return view('create');
    }

    /**
     * Handle form submission and store the data in the database.
     */
    public function store(Request $request)
    {
        // Validate the incoming request data
        $validated = $request->validate([
            'league' => 'required|string|max:255',
            'away' => 'required|string|max:255',
            'home' => 'required|string|max:255',
            'date' => 'required|date',
            'time' => 'required',
            'score' => 'nullable|string|max:255',
        ]);

        // Insert the validated data into the cron_matches table
        CronMatch::create($validated);

        // Redirect back to the form with a success message
        return redirect('/cron-matches/create')->with('success', 'Match added successfully!');
    }

    /**
     * API endpoint for Node.js to fetch all matches with password protection.
     */
    public function index(Request $request)
    {
        $password = $request->input('password');
        $validPassword = env('API_ACCESS_PASSWORD'); // Store the password in your .env file

        if ($password !== $validPassword) {
            return response()->json(['error' => 'Unauthorized'], 401);
        }

        $cronMatches = CronMatch::all();
        return response()->json($cronMatches);
    }
}
